@@ -18,7 +18,7 @@ function availableModule(name) {
     return false;
 }
 
-var pluginName = "com.openexchange.mobile.configuration.gui";
+var pluginName = "com.openexchange.eas.provisioning.ui";
 
 // provide event
 register("Feature_SyncWithMobile", function () {
